@@ -1,15 +1,11 @@
 import os
 import sys
-
 import pytest
 from dotenv import load_dotenv
 from os import environ
 import random
 import string
 import shutil
-from importlib import import_module  # to import the Connector class dynamically
-import importlib.util
-import importlib.machinery
 
 
 def pytest_addoption(parser):
@@ -28,22 +24,21 @@ def pytest_addoption(parser):
 
 @pytest.fixture(scope="session", autouse=True)
 def copy_ini_to_root():
-    shutil.copy(os.path.join(os.path.join(os.path.dirname(__file__), "../"), "pytest.txt"),
+    shutil.copy(os.path.join(os.path.dirname(__file__), "pytest.txt"),
                 os.path.abspath("pytest.ini"))
 
 
-
 @pytest.fixture(scope="session")
 def module_name(pytestconfig):
     return pytestconfig.getoption("file")
 
 
 @pytest.fixture(scope="session",
-                autouse=True)  # FIXME: make this pull the class from the session, not just the session itself
+                autouse=True)
 def connector_class():
     """ This takes in the connector file name and tries to import it """
     try:
-        path = os.path.abspath(os.path.join(os.path.dirname(__file__), "../../../../"))
+        path = os.path.abspath(os.path.join(os.path.dirname(__file__), "..\\..\\..\\..\\"))
         print(path)
         if not path in sys.path:
             sys.path.insert(1, path)
